.. _tensorstore-drivers:

Drivers
=======

.. toctree::
   :maxdepth: 1

   cast/index
   downsample/index
   array/index
   stack/index

Single file drivers
-------------------

.. toctree::
   :maxdepth: 1

   json/index
   image/avif/index
   image/bmp/index
   image/jpeg/index
   image/png/index
   image/tiff/index
   image/webp/index

.. _chunked-drivers:

Chunked storage drivers
-----------------------

.. toctree::
   :maxdepth: 1

   zarr/index
   n5/index
   neuroglancer_precomputed/index

.. json:schema:: KeyValueStoreBackedChunkDriver

.. json:schema:: CacheRevalidationBound
